"""
ReactiveStreams
~~~~~~~~~~~~~~~

Abstract base class definitions for ReactiveStreams Publisher/Subsciber.
"""

from reactivestreams.publisher import Publisher
from reactivestreams.subscriber import Subscriber
from reactivestreams.subscription import Subscription


def reactivestreams():
    return 'reactivestreams-0.1'
