# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: payment_state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_model_pb2 as common__model__pb2
from . import payment_model_pb2 as payment__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='payment_state.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13payment_state.proto\x12\x16\x63om.elarian.hera.proto\x1a\x12\x63ommon_model.proto\x1a\x13payment_model.proto\"\xc2\x03\n\x0cPaymentState\x12@\n\x10\x63ustomer_numbers\x18\x01 \x03(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x45\n\x0f\x63hannel_numbers\x18\x02 \x03(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12\x43\n\x0ftransaction_log\x18\x03 \x03(\x0b\x32*.com.elarian.hera.proto.PaymentTransaction\x12H\n\x14pending_transactions\x18\x04 \x03(\x0b\x32*.com.elarian.hera.proto.PaymentTransaction\x12\x42\n\x07wallets\x18\x05 \x03(\x0b\x32\x31.com.elarian.hera.proto.PaymentState.WalletsEntry\x1aV\n\x0cWalletsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.com.elarian.hera.proto.PaymentBalance:\x02\x38\x01\x62\x06proto3'
  ,
  dependencies=[common__model__pb2.DESCRIPTOR,payment__model__pb2.DESCRIPTOR,])




_PAYMENTSTATE_WALLETSENTRY = _descriptor.Descriptor(
  name='WalletsEntry',
  full_name='com.elarian.hera.proto.PaymentState.WalletsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.PaymentState.WalletsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.PaymentState.WalletsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=539,
)

_PAYMENTSTATE = _descriptor.Descriptor(
  name='PaymentState',
  full_name='com.elarian.hera.proto.PaymentState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_numbers', full_name='com.elarian.hera.proto.PaymentState.customer_numbers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_numbers', full_name='com.elarian.hera.proto.PaymentState.channel_numbers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_log', full_name='com.elarian.hera.proto.PaymentState.transaction_log', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_transactions', full_name='com.elarian.hera.proto.PaymentState.pending_transactions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallets', full_name='com.elarian.hera.proto.PaymentState.wallets', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PAYMENTSTATE_WALLETSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=539,
)

_PAYMENTSTATE_WALLETSENTRY.fields_by_name['value'].message_type = payment__model__pb2._PAYMENTBALANCE
_PAYMENTSTATE_WALLETSENTRY.containing_type = _PAYMENTSTATE
_PAYMENTSTATE.fields_by_name['customer_numbers'].message_type = common__model__pb2._CUSTOMERNUMBER
_PAYMENTSTATE.fields_by_name['channel_numbers'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_PAYMENTSTATE.fields_by_name['transaction_log'].message_type = payment__model__pb2._PAYMENTTRANSACTION
_PAYMENTSTATE.fields_by_name['pending_transactions'].message_type = payment__model__pb2._PAYMENTTRANSACTION
_PAYMENTSTATE.fields_by_name['wallets'].message_type = _PAYMENTSTATE_WALLETSENTRY
DESCRIPTOR.message_types_by_name['PaymentState'] = _PAYMENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PaymentState = _reflection.GeneratedProtocolMessageType('PaymentState', (_message.Message,), {

  'WalletsEntry' : _reflection.GeneratedProtocolMessageType('WalletsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PAYMENTSTATE_WALLETSENTRY,
    '__module__' : 'payment_state_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentState.WalletsEntry)
    })
  ,
  'DESCRIPTOR' : _PAYMENTSTATE,
  '__module__' : 'payment_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentState)
  })
_sym_db.RegisterMessage(PaymentState)
_sym_db.RegisterMessage(PaymentState.WalletsEntry)


_PAYMENTSTATE_WALLETSENTRY._options = None
# @@protoc_insertion_point(module_scope)
