# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: activity_state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import common_model_pb2 as common__model__pb2
from . import activity_model_pb2 as activity__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='activity_state.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x61\x63tivity_state.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12\x63ommon_model.proto\x1a\x14\x61\x63tivity_model.proto\"\xe0\x02\n\x14\x41\x63tivitySessionState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x45\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32-.com.elarian.hera.proto.ActivityChannelNumber\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12<\n\nactivities\x18\x05 \x03(\x0b\x32(.com.elarian.hera.proto.CustomerActivity\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x91\x01\n\rActivityState\x12>\n\x08sessions\x18\x01 \x03(\x0b\x32,.com.elarian.hera.proto.ActivitySessionState\x12@\n\x10\x63ustomer_numbers\x18\x02 \x03(\x0b\x32&.com.elarian.hera.proto.CustomerNumberb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,activity__model__pb2.DESCRIPTOR,])




_ACTIVITYSESSIONSTATE = _descriptor.Descriptor(
  name='ActivitySessionState',
  full_name='com.elarian.hera.proto.ActivitySessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ActivitySessionState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ActivitySessionState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.ActivitySessionState.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.ActivitySessionState.app_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activities', full_name='com.elarian.hera.proto.ActivitySessionState.activities', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.ActivitySessionState.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='com.elarian.hera.proto.ActivitySessionState.updated_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=476,
)


_ACTIVITYSTATE = _descriptor.Descriptor(
  name='ActivityState',
  full_name='com.elarian.hera.proto.ActivityState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.ActivityState.sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_numbers', full_name='com.elarian.hera.proto.ActivityState.customer_numbers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=624,
)

_ACTIVITYSESSIONSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_ACTIVITYSESSIONSTATE.fields_by_name['channel_number'].message_type = activity__model__pb2._ACTIVITYCHANNELNUMBER
_ACTIVITYSESSIONSTATE.fields_by_name['activities'].message_type = activity__model__pb2._CUSTOMERACTIVITY
_ACTIVITYSESSIONSTATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYSESSIONSTATE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVITYSTATE.fields_by_name['sessions'].message_type = _ACTIVITYSESSIONSTATE
_ACTIVITYSTATE.fields_by_name['customer_numbers'].message_type = common__model__pb2._CUSTOMERNUMBER
DESCRIPTOR.message_types_by_name['ActivitySessionState'] = _ACTIVITYSESSIONSTATE
DESCRIPTOR.message_types_by_name['ActivityState'] = _ACTIVITYSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivitySessionState = _reflection.GeneratedProtocolMessageType('ActivitySessionState', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSESSIONSTATE,
  '__module__' : 'activity_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ActivitySessionState)
  })
_sym_db.RegisterMessage(ActivitySessionState)

ActivityState = _reflection.GeneratedProtocolMessageType('ActivityState', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYSTATE,
  '__module__' : 'activity_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ActivityState)
  })
_sym_db.RegisterMessage(ActivityState)


# @@protoc_insertion_point(module_scope)
