# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: payment_model.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import common_model_pb2 as common__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='payment_model.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13payment_model.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12\x63ommon_model.proto\"_\n\x14PaymentChannelNumber\x12\x37\n\x07\x63hannel\x18\x01 \x01(\x0e\x32&.com.elarian.hera.proto.PaymentChannel\x12\x0e\n\x06number\x18\x02 \x01(\t\"\xa9\x01\n\x19PendingPaymentTransaction\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12/\n\tconverted\x18\x03 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\"\xc4\x02\n\x0ePaymentBalance\x12\x15\n\rcurrency_code\x18\x01 \x01(\t\x12/\n\tavailable\x18\x02 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12,\n\x06\x61\x63tual\x18\x03 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12\x44\n\x07pending\x18\x04 \x03(\x0b\x32\x33.com.elarian.hera.proto.PaymentBalance.PendingEntry\x12\x13\n\x0bsequence_nr\x18\x05 \x01(\x04\x1a\x61\n\x0cPendingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.com.elarian.hera.proto.PendingPaymentTransaction:\x02\x38\x01\",\n\x18PaymentPurseCounterParty\x12\x10\n\x08purse_id\x18\x01 \x01(\t\"C\n\x19PaymentWalletCounterParty\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x11\n\twallet_id\x18\x02 \x01(\t\"\xa4\x01\n\x1bPaymentCustomerCounterParty\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x44\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\"\xa7\x01\n\x1aPaymentChannelCounterParty\x12\x44\n\x0e\x63hannel_number\x18\x01 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12\x14\n\x0c\x63hannel_code\x18\x02 \x01(\x05\x12-\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb6\x02\n\x13PaymentCounterParty\x12G\n\x08\x63ustomer\x18\x01 \x01(\x0b\x32\x33.com.elarian.hera.proto.PaymentCustomerCounterPartyH\x00\x12\x41\n\x05purse\x18\x02 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x43\n\x06wallet\x18\x03 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x45\n\x07\x63hannel\x18\x04 \x01(\x0b\x32\x32.com.elarian.hera.proto.PaymentChannelCounterPartyH\x00\x42\x07\n\x05party\"\xa3\x03\n\x12PaymentTransaction\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12,\n\x06\x61pp_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0b\x64\x65\x62it_party\x18\x04 \x01(\x0b\x32+.com.elarian.hera.proto.PaymentCounterParty\x12\x41\n\x0c\x63redit_party\x18\x05 \x01(\x0b\x32+.com.elarian.hera.proto.PaymentCounterParty\x12+\n\x05value\x18\x06 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12\x35\n\x06status\x18\x07 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp*O\n\x0ePaymentChannel\x12\x1f\n\x1bPAYMENT_CHANNEL_UNSPECIFIED\x10\x00\x12\x1c\n\x18PAYMENT_CHANNEL_CELLULAR\x10\x01*\xe1\x05\n\rPaymentStatus\x12\x1e\n\x1aPAYMENT_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15PAYMENT_STATUS_QUEUED\x10\x64\x12\'\n#PAYMENT_STATUS_PENDING_CONFIRMATION\x10\x65\x12%\n!PAYMENT_STATUS_PENDING_VALIDATION\x10\x66\x12\x1c\n\x18PAYMENT_STATUS_VALIDATED\x10g\x12#\n\x1ePAYMENT_STATUS_INVALID_REQUEST\x10\xc8\x01\x12!\n\x1cPAYMENT_STATUS_NOT_SUPPORTED\x10\xc9\x01\x12&\n!PAYMENT_STATUS_INSUFFICIENT_FUNDS\x10\xca\x01\x12%\n PAYMENT_STATUS_APPLICATION_ERROR\x10\xcb\x01\x12\x1f\n\x1aPAYMENT_STATUS_NOT_ALLOWED\x10\xcc\x01\x12%\n PAYMENT_STATUS_DUPLICATE_REQUEST\x10\xcd\x01\x12!\n\x1cPAYMENT_STATUS_INVALID_PURSE\x10\xce\x01\x12\"\n\x1dPAYMENT_STATUS_INVALID_WALLET\x10\xcf\x01\x12.\n)PAYMENT_STATUS_DECOMMISSIONED_CUSTOMER_ID\x10\xab\x02\x12\x1b\n\x16PAYMENT_STATUS_SUCCESS\x10\xac\x02\x12 \n\x1bPAYMENT_STATUS_PASS_THROUGH\x10\xad\x02\x12\x1a\n\x15PAYMENT_STATUS_FAILED\x10\x90\x03\x12\x1d\n\x18PAYMENT_STATUS_THROTTLED\x10\x91\x03\x12\x1b\n\x16PAYMENT_STATUS_EXPIRED\x10\x92\x03\x12\x1c\n\x17PAYMENT_STATUS_REJECTED\x10\x93\x03\x12\x1c\n\x17PAYMENT_STATUS_REVERSED\x10\xf4\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,])

_PAYMENTCHANNEL = _descriptor.EnumDescriptor(
  name='PaymentChannel',
  full_name='com.elarian.hera.proto.PaymentChannel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_CHANNEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_CHANNEL_CELLULAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1915,
  serialized_end=1994,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTCHANNEL)

PaymentChannel = enum_type_wrapper.EnumTypeWrapper(_PAYMENTCHANNEL)
_PAYMENTSTATUS = _descriptor.EnumDescriptor(
  name='PaymentStatus',
  full_name='com.elarian.hera.proto.PaymentStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_QUEUED', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_PENDING_CONFIRMATION', index=2, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_PENDING_VALIDATION', index=3, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_VALIDATED', index=4, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_INVALID_REQUEST', index=5, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_NOT_SUPPORTED', index=6, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_INSUFFICIENT_FUNDS', index=7, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_APPLICATION_ERROR', index=8, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_NOT_ALLOWED', index=9, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_DUPLICATE_REQUEST', index=10, number=205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_INVALID_PURSE', index=11, number=206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_INVALID_WALLET', index=12, number=207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_DECOMMISSIONED_CUSTOMER_ID', index=13, number=299,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_SUCCESS', index=14, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_PASS_THROUGH', index=15, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_FAILED', index=16, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_THROTTLED', index=17, number=401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_EXPIRED', index=18, number=402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_REJECTED', index=19, number=403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYMENT_STATUS_REVERSED', index=20, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1997,
  serialized_end=2734,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTSTATUS)

PaymentStatus = enum_type_wrapper.EnumTypeWrapper(_PAYMENTSTATUS)
PAYMENT_CHANNEL_UNSPECIFIED = 0
PAYMENT_CHANNEL_CELLULAR = 1
PAYMENT_STATUS_UNSPECIFIED = 0
PAYMENT_STATUS_QUEUED = 100
PAYMENT_STATUS_PENDING_CONFIRMATION = 101
PAYMENT_STATUS_PENDING_VALIDATION = 102
PAYMENT_STATUS_VALIDATED = 103
PAYMENT_STATUS_INVALID_REQUEST = 200
PAYMENT_STATUS_NOT_SUPPORTED = 201
PAYMENT_STATUS_INSUFFICIENT_FUNDS = 202
PAYMENT_STATUS_APPLICATION_ERROR = 203
PAYMENT_STATUS_NOT_ALLOWED = 204
PAYMENT_STATUS_DUPLICATE_REQUEST = 205
PAYMENT_STATUS_INVALID_PURSE = 206
PAYMENT_STATUS_INVALID_WALLET = 207
PAYMENT_STATUS_DECOMMISSIONED_CUSTOMER_ID = 299
PAYMENT_STATUS_SUCCESS = 300
PAYMENT_STATUS_PASS_THROUGH = 301
PAYMENT_STATUS_FAILED = 400
PAYMENT_STATUS_THROTTLED = 401
PAYMENT_STATUS_EXPIRED = 402
PAYMENT_STATUS_REJECTED = 403
PAYMENT_STATUS_REVERSED = 500



_PAYMENTCHANNELNUMBER = _descriptor.Descriptor(
  name='PaymentChannelNumber',
  full_name='com.elarian.hera.proto.PaymentChannelNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='com.elarian.hera.proto.PaymentChannelNumber.channel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='com.elarian.hera.proto.PaymentChannelNumber.number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=227,
)


_PENDINGPAYMENTTRANSACTION = _descriptor.Descriptor(
  name='PendingPaymentTransaction',
  full_name='com.elarian.hera.proto.PendingPaymentTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.PendingPaymentTransaction.created_at', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.PendingPaymentTransaction.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='converted', full_name='com.elarian.hera.proto.PendingPaymentTransaction.converted', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=399,
)


_PAYMENTBALANCE_PENDINGENTRY = _descriptor.Descriptor(
  name='PendingEntry',
  full_name='com.elarian.hera.proto.PaymentBalance.PendingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.PaymentBalance.PendingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.PaymentBalance.PendingEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=726,
)

_PAYMENTBALANCE = _descriptor.Descriptor(
  name='PaymentBalance',
  full_name='com.elarian.hera.proto.PaymentBalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='com.elarian.hera.proto.PaymentBalance.currency_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='com.elarian.hera.proto.PaymentBalance.available', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actual', full_name='com.elarian.hera.proto.PaymentBalance.actual', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending', full_name='com.elarian.hera.proto.PaymentBalance.pending', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_nr', full_name='com.elarian.hera.proto.PaymentBalance.sequence_nr', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PAYMENTBALANCE_PENDINGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=726,
)


_PAYMENTPURSECOUNTERPARTY = _descriptor.Descriptor(
  name='PaymentPurseCounterParty',
  full_name='com.elarian.hera.proto.PaymentPurseCounterParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='purse_id', full_name='com.elarian.hera.proto.PaymentPurseCounterParty.purse_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=772,
)


_PAYMENTWALLETCOUNTERPARTY = _descriptor.Descriptor(
  name='PaymentWalletCounterParty',
  full_name='com.elarian.hera.proto.PaymentWalletCounterParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.PaymentWalletCounterParty.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet_id', full_name='com.elarian.hera.proto.PaymentWalletCounterParty.wallet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=841,
)


_PAYMENTCUSTOMERCOUNTERPARTY = _descriptor.Descriptor(
  name='PaymentCustomerCounterParty',
  full_name='com.elarian.hera.proto.PaymentCustomerCounterParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.PaymentCustomerCounterParty.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.PaymentCustomerCounterParty.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=1008,
)


_PAYMENTCHANNELCOUNTERPARTY = _descriptor.Descriptor(
  name='PaymentChannelCounterParty',
  full_name='com.elarian.hera.proto.PaymentChannelCounterParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.PaymentChannelCounterParty.channel_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_code', full_name='com.elarian.hera.proto.PaymentChannelCounterParty.channel_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='com.elarian.hera.proto.PaymentChannelCounterParty.account', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1178,
)


_PAYMENTCOUNTERPARTY = _descriptor.Descriptor(
  name='PaymentCounterParty',
  full_name='com.elarian.hera.proto.PaymentCounterParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer', full_name='com.elarian.hera.proto.PaymentCounterParty.customer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.PaymentCounterParty.purse', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.PaymentCounterParty.wallet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='com.elarian.hera.proto.PaymentCounterParty.channel', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='party', full_name='com.elarian.hera.proto.PaymentCounterParty.party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1181,
  serialized_end=1491,
)


_PAYMENTTRANSACTION = _descriptor.Descriptor(
  name='PaymentTransaction',
  full_name='com.elarian.hera.proto.PaymentTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.PaymentTransaction.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.PaymentTransaction.app_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debit_party', full_name='com.elarian.hera.proto.PaymentTransaction.debit_party', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credit_party', full_name='com.elarian.hera.proto.PaymentTransaction.credit_party', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.PaymentTransaction.value', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.PaymentTransaction.status', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.PaymentTransaction.created_at', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='com.elarian.hera.proto.PaymentTransaction.updated_at', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1494,
  serialized_end=1913,
)

_PAYMENTCHANNELNUMBER.fields_by_name['channel'].enum_type = _PAYMENTCHANNEL
_PENDINGPAYMENTTRANSACTION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PENDINGPAYMENTTRANSACTION.fields_by_name['value'].message_type = common__model__pb2._CASH
_PENDINGPAYMENTTRANSACTION.fields_by_name['converted'].message_type = common__model__pb2._CASH
_PAYMENTBALANCE_PENDINGENTRY.fields_by_name['value'].message_type = _PENDINGPAYMENTTRANSACTION
_PAYMENTBALANCE_PENDINGENTRY.containing_type = _PAYMENTBALANCE
_PAYMENTBALANCE.fields_by_name['available'].message_type = common__model__pb2._CASH
_PAYMENTBALANCE.fields_by_name['actual'].message_type = common__model__pb2._CASH
_PAYMENTBALANCE.fields_by_name['pending'].message_type = _PAYMENTBALANCE_PENDINGENTRY
_PAYMENTCUSTOMERCOUNTERPARTY.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_PAYMENTCUSTOMERCOUNTERPARTY.fields_by_name['channel_number'].message_type = _PAYMENTCHANNELNUMBER
_PAYMENTCHANNELCOUNTERPARTY.fields_by_name['channel_number'].message_type = _PAYMENTCHANNELNUMBER
_PAYMENTCHANNELCOUNTERPARTY.fields_by_name['account'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PAYMENTCOUNTERPARTY.fields_by_name['customer'].message_type = _PAYMENTCUSTOMERCOUNTERPARTY
_PAYMENTCOUNTERPARTY.fields_by_name['purse'].message_type = _PAYMENTPURSECOUNTERPARTY
_PAYMENTCOUNTERPARTY.fields_by_name['wallet'].message_type = _PAYMENTWALLETCOUNTERPARTY
_PAYMENTCOUNTERPARTY.fields_by_name['channel'].message_type = _PAYMENTCHANNELCOUNTERPARTY
_PAYMENTCOUNTERPARTY.oneofs_by_name['party'].fields.append(
  _PAYMENTCOUNTERPARTY.fields_by_name['customer'])
_PAYMENTCOUNTERPARTY.fields_by_name['customer'].containing_oneof = _PAYMENTCOUNTERPARTY.oneofs_by_name['party']
_PAYMENTCOUNTERPARTY.oneofs_by_name['party'].fields.append(
  _PAYMENTCOUNTERPARTY.fields_by_name['purse'])
_PAYMENTCOUNTERPARTY.fields_by_name['purse'].containing_oneof = _PAYMENTCOUNTERPARTY.oneofs_by_name['party']
_PAYMENTCOUNTERPARTY.oneofs_by_name['party'].fields.append(
  _PAYMENTCOUNTERPARTY.fields_by_name['wallet'])
_PAYMENTCOUNTERPARTY.fields_by_name['wallet'].containing_oneof = _PAYMENTCOUNTERPARTY.oneofs_by_name['party']
_PAYMENTCOUNTERPARTY.oneofs_by_name['party'].fields.append(
  _PAYMENTCOUNTERPARTY.fields_by_name['channel'])
_PAYMENTCOUNTERPARTY.fields_by_name['channel'].containing_oneof = _PAYMENTCOUNTERPARTY.oneofs_by_name['party']
_PAYMENTTRANSACTION.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PAYMENTTRANSACTION.fields_by_name['debit_party'].message_type = _PAYMENTCOUNTERPARTY
_PAYMENTTRANSACTION.fields_by_name['credit_party'].message_type = _PAYMENTCOUNTERPARTY
_PAYMENTTRANSACTION.fields_by_name['value'].message_type = common__model__pb2._CASH
_PAYMENTTRANSACTION.fields_by_name['status'].enum_type = _PAYMENTSTATUS
_PAYMENTTRANSACTION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PAYMENTTRANSACTION.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['PaymentChannelNumber'] = _PAYMENTCHANNELNUMBER
DESCRIPTOR.message_types_by_name['PendingPaymentTransaction'] = _PENDINGPAYMENTTRANSACTION
DESCRIPTOR.message_types_by_name['PaymentBalance'] = _PAYMENTBALANCE
DESCRIPTOR.message_types_by_name['PaymentPurseCounterParty'] = _PAYMENTPURSECOUNTERPARTY
DESCRIPTOR.message_types_by_name['PaymentWalletCounterParty'] = _PAYMENTWALLETCOUNTERPARTY
DESCRIPTOR.message_types_by_name['PaymentCustomerCounterParty'] = _PAYMENTCUSTOMERCOUNTERPARTY
DESCRIPTOR.message_types_by_name['PaymentChannelCounterParty'] = _PAYMENTCHANNELCOUNTERPARTY
DESCRIPTOR.message_types_by_name['PaymentCounterParty'] = _PAYMENTCOUNTERPARTY
DESCRIPTOR.message_types_by_name['PaymentTransaction'] = _PAYMENTTRANSACTION
DESCRIPTOR.enum_types_by_name['PaymentChannel'] = _PAYMENTCHANNEL
DESCRIPTOR.enum_types_by_name['PaymentStatus'] = _PAYMENTSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PaymentChannelNumber = _reflection.GeneratedProtocolMessageType('PaymentChannelNumber', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCHANNELNUMBER,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentChannelNumber)
  })
_sym_db.RegisterMessage(PaymentChannelNumber)

PendingPaymentTransaction = _reflection.GeneratedProtocolMessageType('PendingPaymentTransaction', (_message.Message,), {
  'DESCRIPTOR' : _PENDINGPAYMENTTRANSACTION,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PendingPaymentTransaction)
  })
_sym_db.RegisterMessage(PendingPaymentTransaction)

PaymentBalance = _reflection.GeneratedProtocolMessageType('PaymentBalance', (_message.Message,), {

  'PendingEntry' : _reflection.GeneratedProtocolMessageType('PendingEntry', (_message.Message,), {
    'DESCRIPTOR' : _PAYMENTBALANCE_PENDINGENTRY,
    '__module__' : 'payment_model_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentBalance.PendingEntry)
    })
  ,
  'DESCRIPTOR' : _PAYMENTBALANCE,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentBalance)
  })
_sym_db.RegisterMessage(PaymentBalance)
_sym_db.RegisterMessage(PaymentBalance.PendingEntry)

PaymentPurseCounterParty = _reflection.GeneratedProtocolMessageType('PaymentPurseCounterParty', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTPURSECOUNTERPARTY,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentPurseCounterParty)
  })
_sym_db.RegisterMessage(PaymentPurseCounterParty)

PaymentWalletCounterParty = _reflection.GeneratedProtocolMessageType('PaymentWalletCounterParty', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTWALLETCOUNTERPARTY,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentWalletCounterParty)
  })
_sym_db.RegisterMessage(PaymentWalletCounterParty)

PaymentCustomerCounterParty = _reflection.GeneratedProtocolMessageType('PaymentCustomerCounterParty', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCUSTOMERCOUNTERPARTY,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentCustomerCounterParty)
  })
_sym_db.RegisterMessage(PaymentCustomerCounterParty)

PaymentChannelCounterParty = _reflection.GeneratedProtocolMessageType('PaymentChannelCounterParty', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCHANNELCOUNTERPARTY,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentChannelCounterParty)
  })
_sym_db.RegisterMessage(PaymentChannelCounterParty)

PaymentCounterParty = _reflection.GeneratedProtocolMessageType('PaymentCounterParty', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTCOUNTERPARTY,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentCounterParty)
  })
_sym_db.RegisterMessage(PaymentCounterParty)

PaymentTransaction = _reflection.GeneratedProtocolMessageType('PaymentTransaction', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTTRANSACTION,
  '__module__' : 'payment_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.PaymentTransaction)
  })
_sym_db.RegisterMessage(PaymentTransaction)


_PAYMENTBALANCE_PENDINGENTRY._options = None
# @@protoc_insertion_point(module_scope)
