# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app_state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_model_pb2 as common__model__pb2
import app_model_pb2 as app__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='app_state.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0f\x61pp_state.proto\x12\x16\x63om.elarian.hera.proto\x1a\x12\x63ommon_model.proto\x1a\x0f\x61pp_model.proto\"{\n\x08\x41ppState\x12\x32\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32$.com.elarian.hera.proto.DataMapValue\x12;\n\treminders\x18\x02 \x03(\x0b\x32(.com.elarian.hera.proto.CustomerReminderb\x06proto3'
  ,
  dependencies=[common__model__pb2.DESCRIPTOR,app__model__pb2.DESCRIPTOR,])




_APPSTATE = _descriptor.Descriptor(
  name='AppState',
  full_name='com.elarian.hera.proto.AppState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='com.elarian.hera.proto.AppState.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reminders', full_name='com.elarian.hera.proto.AppState.reminders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=203,
)

_APPSTATE.fields_by_name['data'].message_type = common__model__pb2._DATAMAPVALUE
_APPSTATE.fields_by_name['reminders'].message_type = app__model__pb2._CUSTOMERREMINDER
DESCRIPTOR.message_types_by_name['AppState'] = _APPSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AppState = _reflection.GeneratedProtocolMessageType('AppState', (_message.Message,), {
  'DESCRIPTOR' : _APPSTATE,
  '__module__' : 'app_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.AppState)
  })
_sym_db.RegisterMessage(AppState)


# @@protoc_insertion_point(module_scope)
