# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: activity_model.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='activity_model.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14\x61\x63tivity_model.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"a\n\x15\x41\x63tivityChannelNumber\x12\x38\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\'.com.elarian.hera.proto.ActivityChannel\x12\x0e\n\x06number\x18\x02 \x01(\t\"\xd0\x01\n\x10\x43ustomerActivity\x12\x0b\n\x03key\x18\x01 \x01(\t\x12L\n\nproperties\x18\x02 \x03(\x0b\x32\x38.com.elarian.hera.proto.CustomerActivity.PropertiesEntry\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*j\n\x0f\x41\x63tivityChannel\x12 \n\x1c\x41\x43TIVITY_CHANNEL_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41\x43TIVITY_CHANNEL_WEB\x10\x01\x12\x1b\n\x17\x41\x43TIVITY_CHANNEL_MOBILE\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ACTIVITYCHANNEL = _descriptor.EnumDescriptor(
  name='ActivityChannel',
  full_name='com.elarian.hera.proto.ActivityChannel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_CHANNEL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_CHANNEL_WEB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVITY_CHANNEL_MOBILE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=391,
  serialized_end=497,
)
_sym_db.RegisterEnumDescriptor(_ACTIVITYCHANNEL)

ActivityChannel = enum_type_wrapper.EnumTypeWrapper(_ACTIVITYCHANNEL)
ACTIVITY_CHANNEL_UNSPECIFIED = 0
ACTIVITY_CHANNEL_WEB = 1
ACTIVITY_CHANNEL_MOBILE = 2



_ACTIVITYCHANNELNUMBER = _descriptor.Descriptor(
  name='ActivityChannelNumber',
  full_name='com.elarian.hera.proto.ActivityChannelNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='com.elarian.hera.proto.ActivityChannelNumber.channel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='com.elarian.hera.proto.ActivityChannelNumber.number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=178,
)


_CUSTOMERACTIVITY_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='com.elarian.hera.proto.CustomerActivity.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CustomerActivity.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.CustomerActivity.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=389,
)

_CUSTOMERACTIVITY = _descriptor.Descriptor(
  name='CustomerActivity',
  full_name='com.elarian.hera.proto.CustomerActivity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.elarian.hera.proto.CustomerActivity.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='com.elarian.hera.proto.CustomerActivity.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.CustomerActivity.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMERACTIVITY_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=389,
)

_ACTIVITYCHANNELNUMBER.fields_by_name['channel'].enum_type = _ACTIVITYCHANNEL
_CUSTOMERACTIVITY_PROPERTIESENTRY.containing_type = _CUSTOMERACTIVITY
_CUSTOMERACTIVITY.fields_by_name['properties'].message_type = _CUSTOMERACTIVITY_PROPERTIESENTRY
_CUSTOMERACTIVITY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ActivityChannelNumber'] = _ACTIVITYCHANNELNUMBER
DESCRIPTOR.message_types_by_name['CustomerActivity'] = _CUSTOMERACTIVITY
DESCRIPTOR.enum_types_by_name['ActivityChannel'] = _ACTIVITYCHANNEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivityChannelNumber = _reflection.GeneratedProtocolMessageType('ActivityChannelNumber', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVITYCHANNELNUMBER,
  '__module__' : 'activity_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ActivityChannelNumber)
  })
_sym_db.RegisterMessage(ActivityChannelNumber)

CustomerActivity = _reflection.GeneratedProtocolMessageType('CustomerActivity', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMERACTIVITY_PROPERTIESENTRY,
    '__module__' : 'activity_model_pb2'
    # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivity.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CUSTOMERACTIVITY,
  '__module__' : 'activity_model_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CustomerActivity)
  })
_sym_db.RegisterMessage(CustomerActivity)
_sym_db.RegisterMessage(CustomerActivity.PropertiesEntry)


_CUSTOMERACTIVITY_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
