# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: simulator_socket.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_model_pb2 as common__model__pb2
from . import messaging_model_pb2 as messaging__model__pb2
from . import payment_model_pb2 as payment__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='simulator_socket.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16simulator_socket.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x12\x63ommon_model.proto\x1a\x15messaging_model.proto\x1a\x13payment_model.proto\"\xa7\x02\n\x18SimulatorToServerCommand\x12Q\n\x0freceive_message\x18\x01 \x01(\x0b\x32\x36.com.elarian.hera.proto.ReceiveMessageSimulatorCommandH\x00\x12Q\n\x0freceive_payment\x18\x02 \x01(\x0b\x32\x36.com.elarian.hera.proto.ReceivePaymentSimulatorCommandH\x00\x12\\\n\x15update_payment_status\x18\x03 \x01(\x0b\x32;.com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommandH\x00\x42\x07\n\x05\x65ntry\"\xee\x01\n\x1eReceiveMessageSimulatorCommand\x12\x17\n\x0f\x63ustomer_number\x18\x01 \x01(\t\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x39\n\x05parts\x18\x03 \x03(\x0b\x32*.com.elarian.hera.proto.InboundMessageBody\x12\x30\n\nsession_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xfb\x01\n\x1eReceivePaymentSimulatorCommand\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x44\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12\x17\n\x0f\x63ustomer_number\x18\x03 \x01(\t\x12+\n\x05value\x18\x04 \x01(\x0b\x32\x1c.com.elarian.hera.proto.Cash\x12\x35\n\x06status\x18\x05 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"t\n#UpdatePaymentStatusSimulatorCommand\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x35\n\x06status\x18\x02 \x01(\x0e\x32%.com.elarian.hera.proto.PaymentStatus\"~\n\x1dSimulatorToServerCommandReply\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x38\n\x07message\x18\x03 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xef\x03\n\x1dServerToSimulatorNotification\x12P\n\x0csend_message\x18\x01 \x01(\x0b\x32\x38.com.elarian.hera.proto.SendMessageSimulatorNotificationH\x00\x12U\n\x0fmake_voice_call\x18\x02 \x01(\x0b\x32:.com.elarian.hera.proto.MakeVoiceCallSimulatorNotificationH\x00\x12\x61\n\x15send_customer_payment\x18\x03 \x01(\x0b\x32@.com.elarian.hera.proto.SendCustomerPaymentSimulatorNotificationH\x00\x12_\n\x14send_channel_payment\x18\x04 \x01(\x0b\x32?.com.elarian.hera.proto.SendChannelPaymentSimulatorNotificationH\x00\x12X\n\x10\x63heckout_payment\x18\x05 \x01(\x0b\x32<.com.elarian.hera.proto.CheckoutPaymentSimulatorNotificationH\x00\x42\x07\n\x05\x65ntry\"$\n\"ServerToSimulatorNotificationReply\"\x9e\x02\n SendMessageSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x12\n\nmessage_id\x18\x03 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x04 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x05 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x07message\x18\x06 \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\xe6\x01\n\"MakeVoiceCallSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x04 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x05 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\"\xc2\x03\n(SendCustomerPaymentSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12\x43\n\x06wallet\x18\x04 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x41\n\x05purse\x18\x05 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x16\n\x0etransaction_id\x18\x06 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x07 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x44\n\x0e\x63hannel_number\x18\x08 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12+\n\x05value\x18\t \x01(\x0b\x32\x1c.com.elarian.hera.proto.CashB\r\n\x0b\x64\x65\x62it_party\"\x9a\x03\n\'SendChannelPaymentSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\t\x12\x43\n\x06wallet\x18\x03 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x41\n\x05purse\x18\x04 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x16\n\x0etransaction_id\x18\x05 \x01(\t\x12\x44\n\x0e\x63hannel_number\x18\x06 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12-\n\x07\x61\x63\x63ount\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x08 \x01(\x0b\x32\x1c.com.elarian.hera.proto.CashB\r\n\x0b\x64\x65\x62it_party\"\xbf\x03\n$CheckoutPaymentSimulatorNotification\x12\x0e\n\x06org_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12\x43\n\x06wallet\x18\x04 \x01(\x0b\x32\x31.com.elarian.hera.proto.PaymentWalletCounterPartyH\x00\x12\x41\n\x05purse\x18\x05 \x01(\x0b\x32\x30.com.elarian.hera.proto.PaymentPurseCounterPartyH\x00\x12\x16\n\x0etransaction_id\x18\x06 \x01(\t\x12?\n\x0f\x63ustomer_number\x18\x07 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x44\n\x0e\x63hannel_number\x18\x08 \x01(\x0b\x32,.com.elarian.hera.proto.PaymentChannelNumber\x12+\n\x05value\x18\t \x01(\x0b\x32\x1c.com.elarian.hera.proto.CashB\x0e\n\x0c\x63redit_partyb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,messaging__model__pb2.DESCRIPTOR,payment__model__pb2.DESCRIPTOR,])




_SIMULATORTOSERVERCOMMAND = _descriptor.Descriptor(
  name='SimulatorToServerCommand',
  full_name='com.elarian.hera.proto.SimulatorToServerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receive_message', full_name='com.elarian.hera.proto.SimulatorToServerCommand.receive_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive_payment', full_name='com.elarian.hera.proto.SimulatorToServerCommand.receive_payment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_payment_status', full_name='com.elarian.hera.proto.SimulatorToServerCommand.update_payment_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.SimulatorToServerCommand.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=147,
  serialized_end=442,
)


_RECEIVEMESSAGESIMULATORCOMMAND = _descriptor.Descriptor(
  name='ReceiveMessageSimulatorCommand',
  full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.customer_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.parts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.ReceiveMessageSimulatorCommand.session_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=683,
)


_RECEIVEPAYMENTSIMULATORCOMMAND = _descriptor.Descriptor(
  name='ReceivePaymentSimulatorCommand',
  full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.customer_number', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.ReceivePaymentSimulatorCommand.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=937,
)


_UPDATEPAYMENTSTATUSSIMULATORCOMMAND = _descriptor.Descriptor(
  name='UpdatePaymentStatusSimulatorCommand',
  full_name='com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1055,
)


_SIMULATORTOSERVERCOMMANDREPLY = _descriptor.Descriptor(
  name='SimulatorToServerCommandReply',
  full_name='com.elarian.hera.proto.SimulatorToServerCommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.SimulatorToServerCommandReply.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='com.elarian.hera.proto.SimulatorToServerCommandReply.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SimulatorToServerCommandReply.message', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1183,
)


_SERVERTOSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='ServerToSimulatorNotification',
  full_name='com.elarian.hera.proto.ServerToSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send_message', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.send_message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='make_voice_call', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.make_voice_call', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_customer_payment', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.send_customer_payment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_channel_payment', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.send_channel_payment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkout_payment', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.checkout_payment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ServerToSimulatorNotification.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1186,
  serialized_end=1681,
)


_SERVERTOSIMULATORNOTIFICATIONREPLY = _descriptor.Descriptor(
  name='ServerToSimulatorNotificationReply',
  full_name='com.elarian.hera.proto.ServerToSimulatorNotificationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1719,
)


_SENDMESSAGESIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='SendMessageSimulatorNotification',
  full_name='com.elarian.hera.proto.SendMessageSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.message_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.customer_number', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.channel_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SendMessageSimulatorNotification.message', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1722,
  serialized_end=2008,
)


_MAKEVOICECALLSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='MakeVoiceCallSimulatorNotification',
  full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.customer_number', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.MakeVoiceCallSimulatorNotification.channel_number', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2011,
  serialized_end=2241,
)


_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='SendCustomerPaymentSimulatorNotification',
  full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.app_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.wallet', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.purse', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.transaction_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.customer_number', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.channel_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='debit_party', full_name='com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification.debit_party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2244,
  serialized_end=2694,
)


_SENDCHANNELPAYMENTSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='SendChannelPaymentSimulatorNotification',
  full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.wallet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.purse', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.transaction_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.channel_number', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.account', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='debit_party', full_name='com.elarian.hera.proto.SendChannelPaymentSimulatorNotification.debit_party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2697,
  serialized_end=3107,
)


_CHECKOUTPAYMENTSIMULATORNOTIFICATION = _descriptor.Descriptor(
  name='CheckoutPaymentSimulatorNotification',
  full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='org_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.org_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.customer_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.app_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wallet', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.wallet', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='purse', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.purse', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.transaction_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.customer_number', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.channel_number', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credit_party', full_name='com.elarian.hera.proto.CheckoutPaymentSimulatorNotification.credit_party',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3110,
  serialized_end=3557,
)

_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_message'].message_type = _RECEIVEMESSAGESIMULATORCOMMAND
_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_payment'].message_type = _RECEIVEPAYMENTSIMULATORCOMMAND
_SIMULATORTOSERVERCOMMAND.fields_by_name['update_payment_status'].message_type = _UPDATEPAYMENTSTATUSSIMULATORCOMMAND
_SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _SIMULATORTOSERVERCOMMAND.fields_by_name['receive_message'])
_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_message'].containing_oneof = _SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry']
_SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _SIMULATORTOSERVERCOMMAND.fields_by_name['receive_payment'])
_SIMULATORTOSERVERCOMMAND.fields_by_name['receive_payment'].containing_oneof = _SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry']
_SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry'].fields.append(
  _SIMULATORTOSERVERCOMMAND.fields_by_name['update_payment_status'])
_SIMULATORTOSERVERCOMMAND.fields_by_name['update_payment_status'].containing_oneof = _SIMULATORTOSERVERCOMMAND.oneofs_by_name['entry']
_RECEIVEMESSAGESIMULATORCOMMAND.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_RECEIVEMESSAGESIMULATORCOMMAND.fields_by_name['parts'].message_type = messaging__model__pb2._INBOUNDMESSAGEBODY
_RECEIVEMESSAGESIMULATORCOMMAND.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEPAYMENTSIMULATORCOMMAND.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_RECEIVEPAYMENTSIMULATORCOMMAND.fields_by_name['value'].message_type = common__model__pb2._CASH
_RECEIVEPAYMENTSIMULATORCOMMAND.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_UPDATEPAYMENTSTATUSSIMULATORCOMMAND.fields_by_name['status'].enum_type = payment__model__pb2._PAYMENTSTATUS
_SIMULATORTOSERVERCOMMANDREPLY.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_message'].message_type = _SENDMESSAGESIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['make_voice_call'].message_type = _MAKEVOICECALLSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_customer_payment'].message_type = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_channel_payment'].message_type = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['checkout_payment'].message_type = _CHECKOUTPAYMENTSIMULATORNOTIFICATION
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_message'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_message'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['make_voice_call'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['make_voice_call'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_customer_payment'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_customer_payment'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_channel_payment'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['send_channel_payment'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry'].fields.append(
  _SERVERTOSIMULATORNOTIFICATION.fields_by_name['checkout_payment'])
_SERVERTOSIMULATORNOTIFICATION.fields_by_name['checkout_payment'].containing_oneof = _SERVERTOSIMULATORNOTIFICATION.oneofs_by_name['entry']
_SENDMESSAGESIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_SENDMESSAGESIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENDMESSAGESIMULATORNOTIFICATION.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_MAKEVOICECALLSIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_MAKEVOICECALLSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].message_type = payment__model__pb2._PAYMENTWALLETCOUNTERPARTY
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].message_type = payment__model__pb2._PAYMENTPURSECOUNTERPARTY
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'])
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].containing_oneof = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'])
_SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].containing_oneof = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].message_type = payment__model__pb2._PAYMENTWALLETCOUNTERPARTY
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].message_type = payment__model__pb2._PAYMENTPURSECOUNTERPARTY
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['account'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'])
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].containing_oneof = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party'].fields.append(
  _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'])
_SENDCHANNELPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].containing_oneof = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['debit_party']
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].message_type = payment__model__pb2._PAYMENTWALLETCOUNTERPARTY
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].message_type = payment__model__pb2._PAYMENTPURSECOUNTERPARTY
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['channel_number'].message_type = payment__model__pb2._PAYMENTCHANNELNUMBER
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['value'].message_type = common__model__pb2._CASH
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party'].fields.append(
  _CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'])
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['wallet'].containing_oneof = _CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party']
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party'].fields.append(
  _CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'])
_CHECKOUTPAYMENTSIMULATORNOTIFICATION.fields_by_name['purse'].containing_oneof = _CHECKOUTPAYMENTSIMULATORNOTIFICATION.oneofs_by_name['credit_party']
DESCRIPTOR.message_types_by_name['SimulatorToServerCommand'] = _SIMULATORTOSERVERCOMMAND
DESCRIPTOR.message_types_by_name['ReceiveMessageSimulatorCommand'] = _RECEIVEMESSAGESIMULATORCOMMAND
DESCRIPTOR.message_types_by_name['ReceivePaymentSimulatorCommand'] = _RECEIVEPAYMENTSIMULATORCOMMAND
DESCRIPTOR.message_types_by_name['UpdatePaymentStatusSimulatorCommand'] = _UPDATEPAYMENTSTATUSSIMULATORCOMMAND
DESCRIPTOR.message_types_by_name['SimulatorToServerCommandReply'] = _SIMULATORTOSERVERCOMMANDREPLY
DESCRIPTOR.message_types_by_name['ServerToSimulatorNotification'] = _SERVERTOSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['ServerToSimulatorNotificationReply'] = _SERVERTOSIMULATORNOTIFICATIONREPLY
DESCRIPTOR.message_types_by_name['SendMessageSimulatorNotification'] = _SENDMESSAGESIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['MakeVoiceCallSimulatorNotification'] = _MAKEVOICECALLSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['SendCustomerPaymentSimulatorNotification'] = _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['SendChannelPaymentSimulatorNotification'] = _SENDCHANNELPAYMENTSIMULATORNOTIFICATION
DESCRIPTOR.message_types_by_name['CheckoutPaymentSimulatorNotification'] = _CHECKOUTPAYMENTSIMULATORNOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimulatorToServerCommand = _reflection.GeneratedProtocolMessageType('SimulatorToServerCommand', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORTOSERVERCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SimulatorToServerCommand)
  })
_sym_db.RegisterMessage(SimulatorToServerCommand)

ReceiveMessageSimulatorCommand = _reflection.GeneratedProtocolMessageType('ReceiveMessageSimulatorCommand', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEMESSAGESIMULATORCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceiveMessageSimulatorCommand)
  })
_sym_db.RegisterMessage(ReceiveMessageSimulatorCommand)

ReceivePaymentSimulatorCommand = _reflection.GeneratedProtocolMessageType('ReceivePaymentSimulatorCommand', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEPAYMENTSIMULATORCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceivePaymentSimulatorCommand)
  })
_sym_db.RegisterMessage(ReceivePaymentSimulatorCommand)

UpdatePaymentStatusSimulatorCommand = _reflection.GeneratedProtocolMessageType('UpdatePaymentStatusSimulatorCommand', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPAYMENTSTATUSSIMULATORCOMMAND,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.UpdatePaymentStatusSimulatorCommand)
  })
_sym_db.RegisterMessage(UpdatePaymentStatusSimulatorCommand)

SimulatorToServerCommandReply = _reflection.GeneratedProtocolMessageType('SimulatorToServerCommandReply', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORTOSERVERCOMMANDREPLY,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SimulatorToServerCommandReply)
  })
_sym_db.RegisterMessage(SimulatorToServerCommandReply)

ServerToSimulatorNotification = _reflection.GeneratedProtocolMessageType('ServerToSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToSimulatorNotification)
  })
_sym_db.RegisterMessage(ServerToSimulatorNotification)

ServerToSimulatorNotificationReply = _reflection.GeneratedProtocolMessageType('ServerToSimulatorNotificationReply', (_message.Message,), {
  'DESCRIPTOR' : _SERVERTOSIMULATORNOTIFICATIONREPLY,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ServerToSimulatorNotificationReply)
  })
_sym_db.RegisterMessage(ServerToSimulatorNotificationReply)

SendMessageSimulatorNotification = _reflection.GeneratedProtocolMessageType('SendMessageSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENDMESSAGESIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendMessageSimulatorNotification)
  })
_sym_db.RegisterMessage(SendMessageSimulatorNotification)

MakeVoiceCallSimulatorNotification = _reflection.GeneratedProtocolMessageType('MakeVoiceCallSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _MAKEVOICECALLSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MakeVoiceCallSimulatorNotification)
  })
_sym_db.RegisterMessage(MakeVoiceCallSimulatorNotification)

SendCustomerPaymentSimulatorNotification = _reflection.GeneratedProtocolMessageType('SendCustomerPaymentSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENDCUSTOMERPAYMENTSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendCustomerPaymentSimulatorNotification)
  })
_sym_db.RegisterMessage(SendCustomerPaymentSimulatorNotification)

SendChannelPaymentSimulatorNotification = _reflection.GeneratedProtocolMessageType('SendChannelPaymentSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _SENDCHANNELPAYMENTSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SendChannelPaymentSimulatorNotification)
  })
_sym_db.RegisterMessage(SendChannelPaymentSimulatorNotification)

CheckoutPaymentSimulatorNotification = _reflection.GeneratedProtocolMessageType('CheckoutPaymentSimulatorNotification', (_message.Message,), {
  'DESCRIPTOR' : _CHECKOUTPAYMENTSIMULATORNOTIFICATION,
  '__module__' : 'simulator_socket_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CheckoutPaymentSimulatorNotification)
  })
_sym_db.RegisterMessage(CheckoutPaymentSimulatorNotification)


# @@protoc_insertion_point(module_scope)
