# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messaging_state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_model_pb2 as common__model__pb2
from . import messaging_model_pb2 as messaging__model__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messaging_state.proto',
  package='com.elarian.hera.proto',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15messaging_state.proto\x12\x16\x63om.elarian.hera.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x12\x63ommon_model.proto\x1a\x15messaging_model.proto\"\xe4\x02\n\x0fReceivedMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\nsession_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bin_reply_to\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08provider\x18\x05 \x01(\x0e\x32-.com.elarian.hera.proto.ChannelNumberProvider\x12,\n\x06\x61pp_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x05parts\x18\x07 \x03(\x0b\x32*.com.elarian.hera.proto.InboundMessageBody\"\x8f\x04\n\x0bSentMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\nsession_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bin_reply_to\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08provider\x18\x05 \x01(\x0e\x32-.com.elarian.hera.proto.ChannelNumberProvider\x12,\n\x06\x61pp_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x06status\x18\x08 \x01(\x0e\x32-.com.elarian.hera.proto.MessageDeliveryStatus\x12?\n\treactions\x18\t \x03(\x0b\x32,.com.elarian.hera.proto.MessageReactionState\x12\x38\n\x07message\x18\n \x01(\x0b\x32\'.com.elarian.hera.proto.OutboundMessage\"\x81\x01\n\x14MessageReactionState\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x08reaction\x18\x02 \x01(\x0e\x32\'.com.elarian.hera.proto.MessageReaction\"R\n\x11MessageReplyToken\x12\r\n\x05token\x18\x01 \x01(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8b\x01\n\x0e\x43hannelMessage\x12;\n\x08received\x18\x01 \x01(\x0b\x32\'.com.elarian.hera.proto.ReceivedMessageH\x00\x12\x33\n\x04sent\x18\x02 \x01(\x0b\x32#.com.elarian.hera.proto.SentMessageH\x00\x42\x07\n\x05\x65ntry\"\xe3\x01\n\x18\x43ompleteMessagingSession\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0f\n\x07\x61pp_ids\x18\x04 \x03(\t\x12\x45\n\nend_reason\x18\x05 \x01(\x0e\x32\x31.com.elarian.hera.proto.MessagingSessionEndReason\"\x95\x03\n\x1c\x42lockedMessagingChannelState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x08messages\x18\x03 \x03(\x0b\x32&.com.elarian.hera.proto.ChannelMessage\x12>\n\x0breply_token\x18\x04 \x01(\x0b\x32).com.elarian.hera.proto.MessageReplyToken\x12\x42\n\x08sessions\x18\x05 \x03(\x0b\x32\x30.com.elarian.hera.proto.CompleteMessagingSession\x12.\n\nblocked_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x94\x03\n\x1b\x41\x63tiveMessagingChannelState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x08messages\x18\x03 \x03(\x0b\x32&.com.elarian.hera.proto.ChannelMessage\x12>\n\x0breply_token\x18\x04 \x01(\x0b\x32).com.elarian.hera.proto.MessageReplyToken\x12\x42\n\x08sessions\x18\x05 \x03(\x0b\x32\x30.com.elarian.hera.proto.CompleteMessagingSession\x12.\n\nallowed_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9c\x04\n\x1eInSessionMessagingChannelState\x12?\n\x0f\x63ustomer_number\x18\x01 \x01(\x0b\x32&.com.elarian.hera.proto.CustomerNumber\x12\x46\n\x0e\x63hannel_number\x18\x02 \x01(\x0b\x32..com.elarian.hera.proto.MessagingChannelNumber\x12\x38\n\x08messages\x18\x03 \x03(\x0b\x32&.com.elarian.hera.proto.ChannelMessage\x12>\n\x0breply_token\x18\x04 \x01(\x0b\x32).com.elarian.hera.proto.MessageReplyToken\x12\x42\n\x08sessions\x18\x05 \x03(\x0b\x32\x30.com.elarian.hera.proto.CompleteMessagingSession\x12.\n\nallowed_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\x07 \x01(\t\x12.\n\nstarted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61pp_ids\x18\n \x03(\t\"\xfe\x01\n\x15MessagingChannelState\x12G\n\x07\x62locked\x18\x01 \x01(\x0b\x32\x34.com.elarian.hera.proto.BlockedMessagingChannelStateH\x00\x12\x45\n\x06\x61\x63tive\x18\x02 \x01(\x0b\x32\x33.com.elarian.hera.proto.ActiveMessagingChannelStateH\x00\x12L\n\nin_session\x18\x03 \x01(\x0b\x32\x36.com.elarian.hera.proto.InSessionMessagingChannelStateH\x00\x42\x07\n\x05state\"Q\n\x0eMessagingState\x12?\n\x08\x63hannels\x18\x01 \x03(\x0b\x32-.com.elarian.hera.proto.MessagingChannelStateb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,common__model__pb2.DESCRIPTOR,messaging__model__pb2.DESCRIPTOR,])




_RECEIVEDMESSAGE = _descriptor.Descriptor(
  name='ReceivedMessage',
  full_name='com.elarian.hera.proto.ReceivedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.ReceivedMessage.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.ReceivedMessage.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.ReceivedMessage.session_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_reply_to', full_name='com.elarian.hera.proto.ReceivedMessage.in_reply_to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='com.elarian.hera.proto.ReceivedMessage.provider', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.ReceivedMessage.app_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parts', full_name='com.elarian.hera.proto.ReceivedMessage.parts', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=546,
)


_SENTMESSAGE = _descriptor.Descriptor(
  name='SentMessage',
  full_name='com.elarian.hera.proto.SentMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='com.elarian.hera.proto.SentMessage.message_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.SentMessage.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.SentMessage.session_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_reply_to', full_name='com.elarian.hera.proto.SentMessage.in_reply_to', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='com.elarian.hera.proto.SentMessage.provider', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='com.elarian.hera.proto.SentMessage.app_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='com.elarian.hera.proto.SentMessage.updated_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='com.elarian.hera.proto.SentMessage.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='com.elarian.hera.proto.SentMessage.reactions', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='com.elarian.hera.proto.SentMessage.message', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=1076,
)


_MESSAGEREACTIONSTATE = _descriptor.Descriptor(
  name='MessageReactionState',
  full_name='com.elarian.hera.proto.MessageReactionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created_at', full_name='com.elarian.hera.proto.MessageReactionState.created_at', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='com.elarian.hera.proto.MessageReactionState.reaction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1208,
)


_MESSAGEREPLYTOKEN = _descriptor.Descriptor(
  name='MessageReplyToken',
  full_name='com.elarian.hera.proto.MessageReplyToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='com.elarian.hera.proto.MessageReplyToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='com.elarian.hera.proto.MessageReplyToken.expires_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1292,
)


_CHANNELMESSAGE = _descriptor.Descriptor(
  name='ChannelMessage',
  full_name='com.elarian.hera.proto.ChannelMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='received', full_name='com.elarian.hera.proto.ChannelMessage.received', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent', full_name='com.elarian.hera.proto.ChannelMessage.sent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='entry', full_name='com.elarian.hera.proto.ChannelMessage.entry',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1295,
  serialized_end=1434,
)


_COMPLETEMESSAGINGSESSION = _descriptor.Descriptor(
  name='CompleteMessagingSession',
  full_name='com.elarian.hera.proto.CompleteMessagingSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.CompleteMessagingSession.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='com.elarian.hera.proto.CompleteMessagingSession.started_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='com.elarian.hera.proto.CompleteMessagingSession.duration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='com.elarian.hera.proto.CompleteMessagingSession.app_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_reason', full_name='com.elarian.hera.proto.CompleteMessagingSession.end_reason', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1437,
  serialized_end=1664,
)


_BLOCKEDMESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='BlockedMessagingChannelState',
  full_name='com.elarian.hera.proto.BlockedMessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.sessions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocked_at', full_name='com.elarian.hera.proto.BlockedMessagingChannelState.blocked_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=2072,
)


_ACTIVEMESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='ActiveMessagingChannelState',
  full_name='com.elarian.hera.proto.ActiveMessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.sessions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_at', full_name='com.elarian.hera.proto.ActiveMessagingChannelState.allowed_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2075,
  serialized_end=2479,
)


_INSESSIONMESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='InSessionMessagingChannelState',
  full_name='com.elarian.hera.proto.InSessionMessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_number', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.customer_number', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.channel_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_token', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.reply_token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessions', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.sessions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_at', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.allowed_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.session_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.started_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.expires_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_ids', full_name='com.elarian.hera.proto.InSessionMessagingChannelState.app_ids', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2482,
  serialized_end=3022,
)


_MESSAGINGCHANNELSTATE = _descriptor.Descriptor(
  name='MessagingChannelState',
  full_name='com.elarian.hera.proto.MessagingChannelState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocked', full_name='com.elarian.hera.proto.MessagingChannelState.blocked', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='com.elarian.hera.proto.MessagingChannelState.active', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_session', full_name='com.elarian.hera.proto.MessagingChannelState.in_session', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='state', full_name='com.elarian.hera.proto.MessagingChannelState.state',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3025,
  serialized_end=3279,
)


_MESSAGINGSTATE = _descriptor.Descriptor(
  name='MessagingState',
  full_name='com.elarian.hera.proto.MessagingState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='com.elarian.hera.proto.MessagingState.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3281,
  serialized_end=3362,
)

_RECEIVEDMESSAGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RECEIVEDMESSAGE.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGE.fields_by_name['in_reply_to'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGE.fields_by_name['provider'].enum_type = common__model__pb2._CHANNELNUMBERPROVIDER
_RECEIVEDMESSAGE.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RECEIVEDMESSAGE.fields_by_name['parts'].message_type = messaging__model__pb2._INBOUNDMESSAGEBODY
_SENTMESSAGE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SENTMESSAGE.fields_by_name['session_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENTMESSAGE.fields_by_name['in_reply_to'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENTMESSAGE.fields_by_name['provider'].enum_type = common__model__pb2._CHANNELNUMBERPROVIDER
_SENTMESSAGE.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SENTMESSAGE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SENTMESSAGE.fields_by_name['status'].enum_type = messaging__model__pb2._MESSAGEDELIVERYSTATUS
_SENTMESSAGE.fields_by_name['reactions'].message_type = _MESSAGEREACTIONSTATE
_SENTMESSAGE.fields_by_name['message'].message_type = messaging__model__pb2._OUTBOUNDMESSAGE
_MESSAGEREACTIONSTATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGEREACTIONSTATE.fields_by_name['reaction'].enum_type = messaging__model__pb2._MESSAGEREACTION
_MESSAGEREPLYTOKEN.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHANNELMESSAGE.fields_by_name['received'].message_type = _RECEIVEDMESSAGE
_CHANNELMESSAGE.fields_by_name['sent'].message_type = _SENTMESSAGE
_CHANNELMESSAGE.oneofs_by_name['entry'].fields.append(
  _CHANNELMESSAGE.fields_by_name['received'])
_CHANNELMESSAGE.fields_by_name['received'].containing_oneof = _CHANNELMESSAGE.oneofs_by_name['entry']
_CHANNELMESSAGE.oneofs_by_name['entry'].fields.append(
  _CHANNELMESSAGE.fields_by_name['sent'])
_CHANNELMESSAGE.fields_by_name['sent'].containing_oneof = _CHANNELMESSAGE.oneofs_by_name['entry']
_COMPLETEMESSAGINGSESSION.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMPLETEMESSAGINGSESSION.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_COMPLETEMESSAGINGSESSION.fields_by_name['end_reason'].enum_type = messaging__model__pb2._MESSAGINGSESSIONENDREASON
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['messages'].message_type = _CHANNELMESSAGE
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['reply_token'].message_type = _MESSAGEREPLYTOKEN
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['sessions'].message_type = _COMPLETEMESSAGINGSESSION
_BLOCKEDMESSAGINGCHANNELSTATE.fields_by_name['blocked_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['messages'].message_type = _CHANNELMESSAGE
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['reply_token'].message_type = _MESSAGEREPLYTOKEN
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['sessions'].message_type = _COMPLETEMESSAGINGSESSION
_ACTIVEMESSAGINGCHANNELSTATE.fields_by_name['allowed_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['customer_number'].message_type = common__model__pb2._CUSTOMERNUMBER
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['channel_number'].message_type = messaging__model__pb2._MESSAGINGCHANNELNUMBER
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['messages'].message_type = _CHANNELMESSAGE
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['reply_token'].message_type = _MESSAGEREPLYTOKEN
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['sessions'].message_type = _COMPLETEMESSAGINGSESSION
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['allowed_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INSESSIONMESSAGINGCHANNELSTATE.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MESSAGINGCHANNELSTATE.fields_by_name['blocked'].message_type = _BLOCKEDMESSAGINGCHANNELSTATE
_MESSAGINGCHANNELSTATE.fields_by_name['active'].message_type = _ACTIVEMESSAGINGCHANNELSTATE
_MESSAGINGCHANNELSTATE.fields_by_name['in_session'].message_type = _INSESSIONMESSAGINGCHANNELSTATE
_MESSAGINGCHANNELSTATE.oneofs_by_name['state'].fields.append(
  _MESSAGINGCHANNELSTATE.fields_by_name['blocked'])
_MESSAGINGCHANNELSTATE.fields_by_name['blocked'].containing_oneof = _MESSAGINGCHANNELSTATE.oneofs_by_name['state']
_MESSAGINGCHANNELSTATE.oneofs_by_name['state'].fields.append(
  _MESSAGINGCHANNELSTATE.fields_by_name['active'])
_MESSAGINGCHANNELSTATE.fields_by_name['active'].containing_oneof = _MESSAGINGCHANNELSTATE.oneofs_by_name['state']
_MESSAGINGCHANNELSTATE.oneofs_by_name['state'].fields.append(
  _MESSAGINGCHANNELSTATE.fields_by_name['in_session'])
_MESSAGINGCHANNELSTATE.fields_by_name['in_session'].containing_oneof = _MESSAGINGCHANNELSTATE.oneofs_by_name['state']
_MESSAGINGSTATE.fields_by_name['channels'].message_type = _MESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['ReceivedMessage'] = _RECEIVEDMESSAGE
DESCRIPTOR.message_types_by_name['SentMessage'] = _SENTMESSAGE
DESCRIPTOR.message_types_by_name['MessageReactionState'] = _MESSAGEREACTIONSTATE
DESCRIPTOR.message_types_by_name['MessageReplyToken'] = _MESSAGEREPLYTOKEN
DESCRIPTOR.message_types_by_name['ChannelMessage'] = _CHANNELMESSAGE
DESCRIPTOR.message_types_by_name['CompleteMessagingSession'] = _COMPLETEMESSAGINGSESSION
DESCRIPTOR.message_types_by_name['BlockedMessagingChannelState'] = _BLOCKEDMESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['ActiveMessagingChannelState'] = _ACTIVEMESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['InSessionMessagingChannelState'] = _INSESSIONMESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['MessagingChannelState'] = _MESSAGINGCHANNELSTATE
DESCRIPTOR.message_types_by_name['MessagingState'] = _MESSAGINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReceivedMessage = _reflection.GeneratedProtocolMessageType('ReceivedMessage', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVEDMESSAGE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ReceivedMessage)
  })
_sym_db.RegisterMessage(ReceivedMessage)

SentMessage = _reflection.GeneratedProtocolMessageType('SentMessage', (_message.Message,), {
  'DESCRIPTOR' : _SENTMESSAGE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.SentMessage)
  })
_sym_db.RegisterMessage(SentMessage)

MessageReactionState = _reflection.GeneratedProtocolMessageType('MessageReactionState', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREACTIONSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessageReactionState)
  })
_sym_db.RegisterMessage(MessageReactionState)

MessageReplyToken = _reflection.GeneratedProtocolMessageType('MessageReplyToken', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREPLYTOKEN,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessageReplyToken)
  })
_sym_db.RegisterMessage(MessageReplyToken)

ChannelMessage = _reflection.GeneratedProtocolMessageType('ChannelMessage', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELMESSAGE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ChannelMessage)
  })
_sym_db.RegisterMessage(ChannelMessage)

CompleteMessagingSession = _reflection.GeneratedProtocolMessageType('CompleteMessagingSession', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEMESSAGINGSESSION,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.CompleteMessagingSession)
  })
_sym_db.RegisterMessage(CompleteMessagingSession)

BlockedMessagingChannelState = _reflection.GeneratedProtocolMessageType('BlockedMessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKEDMESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.BlockedMessagingChannelState)
  })
_sym_db.RegisterMessage(BlockedMessagingChannelState)

ActiveMessagingChannelState = _reflection.GeneratedProtocolMessageType('ActiveMessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEMESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.ActiveMessagingChannelState)
  })
_sym_db.RegisterMessage(ActiveMessagingChannelState)

InSessionMessagingChannelState = _reflection.GeneratedProtocolMessageType('InSessionMessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _INSESSIONMESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.InSessionMessagingChannelState)
  })
_sym_db.RegisterMessage(InSessionMessagingChannelState)

MessagingChannelState = _reflection.GeneratedProtocolMessageType('MessagingChannelState', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGCHANNELSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingChannelState)
  })
_sym_db.RegisterMessage(MessagingChannelState)

MessagingState = _reflection.GeneratedProtocolMessageType('MessagingState', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGINGSTATE,
  '__module__' : 'messaging_state_pb2'
  # @@protoc_insertion_point(class_scope:com.elarian.hera.proto.MessagingState)
  })
_sym_db.RegisterMessage(MessagingState)


# @@protoc_insertion_point(module_scope)
